@@ -44,24 +44,24 @@ public class SqlTranslate {
 	private static String BIG_QUERY = "bigquery";
 	private static String IMPALA = "impala";
 	private static String SPARK = "spark";
-
+	
 	protected static class Block extends StringUtils.Token {
 		public boolean isVariable;
 		public String regEx;
-
+		
 		public Block(StringUtils.Token other) {
 			super(other);
 			isVariable = false;
 		}
 	}
-
+	
 	protected static class MatchedPattern {
 		public int start;
 		public int end;
 		public int startToken;
 		public Map<String, String> variableToValue = new HashMap<String, String>();
 	}
-
+	
 	protected static List<Block> parseSearchPattern(String pattern) {
 		List<StringUtils.Token> tokens = StringUtils.tokenizeSql(pattern.toLowerCase());
 		List<Block> blocks = new ArrayList<Block>();
@@ -75,9 +75,11 @@ public class SqlTranslate {
 				boolean escape = false;
 				int nesting = 0;
 				for (int j = i + 2; j < tokens.size(); j++) {
-					if (tokens.get(j).text.equals("\\"))
-						escape = !escape;
-					else if (!escape && tokens.get(j).text.equals("("))
+					if (escape)
+						escape = false;
+					else if (tokens.get(j).text.equals("\\"))
+						escape = true;
+					else if (!escape && tokens.get(j).text.equals("(")) 
 						nesting++;
 					else if (!escape && tokens.get(j).text.equals(")")) {
 						if (nesting == 0) {
@@ -101,7 +103,7 @@ public class SqlTranslate {
 		}
 		return blocks;
 	}
-
+	
 	protected static MatchedPattern search(String sql, List<Block> parsedPattern, int startToken) {
 		String lowercaseSql = sql.toLowerCase();
 		List<StringUtils.Token> tokens = StringUtils.tokenizeSql(lowercaseSql);
@@ -143,7 +145,25 @@ public class SqlTranslate {
 				} else if (nestStack.size() == 0 && matchCount < parsedPattern.size() - 1
 						&& token.text.equals(parsedPattern.get(matchCount + 1).text)) {
 					// Found the token after the variable
-					if (parsedPattern.get(matchCount).regEx != null
+					if (parsedPattern.get(matchCount).regEx != null && matchCount == 0) {
+						// First element of pattern is a regEx. Find last part of string prior to subsequent token that matches regEx:
+						int start = matchesEnd(parsedPattern.get(matchCount).regEx, sql.substring(varStart, token.start));
+						if (start != -1) {
+							matchedPattern.variableToValue.put(parsedPattern.get(matchCount).text,
+									sql.substring(start + varStart, token.start));
+							matchedPattern.start = start + varStart;
+							matchedPattern.startToken = cursor;
+							matchCount += 2;
+							if (matchCount == parsedPattern.size()) {
+								matchedPattern.end = token.end;
+								return matchedPattern;
+							} else if (parsedPattern.get(matchCount).isVariable) {
+								varStart = (cursor < tokens.size() - 1) ? tokens.get(cursor + 1).start : -1;
+							}
+							if (token.text.equals("'") || token.text.equals("'"))
+								inPatternQuote = !inPatternQuote;
+						}
+					} else if (parsedPattern.get(matchCount).regEx != null
 							&& !matches(parsedPattern.get(matchCount).regEx, sql.substring(varStart, token.start))) {
 						// Content didn't match regex
 						matchCount = 0;
@@ -162,15 +182,15 @@ public class SqlTranslate {
 						if (token.text.equals("'") || token.text.equals("'"))
 							inPatternQuote = !inPatternQuote;
 					}
-				} else if (nestStack.size() == 0 && !inPatternQuote
+				} else if (matchCount != 0 && nestStack.size() == 0 && !inPatternQuote
 						&& (token.text.equals(";") || token.text.equals(")"))) { // Not allowed to span multiple SQL
 					// statements or outside of nesting
 					matchCount = 0;
 					cursor = matchedPattern.startToken;
 				} else {
 					if (nestStack.size() != 0 && (nestStack.peek().equals("\"") || nestStack.peek().equals("'"))) { // inside
-																													// quoted
-																													// string
+						// quoted
+						// string
 						if (token.text.equals(nestStack.peek()))
 							nestStack.pop();
 					} else {
@@ -207,7 +227,7 @@ public class SqlTranslate {
 				}
 			}
 			if (matchCount != 0 && cursor == tokens.size() - 1) { // If at end of sql and still didn't finish pattern,
-																	// we're not going to finish it
+				// we're not going to finish it
 				matchCount = 0;
 				cursor = matchedPattern.startToken;
 			}
@@ -215,13 +235,25 @@ public class SqlTranslate {
 		matchedPattern.start = -1;
 		return matchedPattern;
 	}
-
+	
 	private static boolean matches(String regex, String string) {
 		Pattern pattern = Pattern.compile(regex, Pattern.CASE_INSENSITIVE | Pattern.DOTALL | Pattern.MULTILINE);
 		Matcher matcher = pattern.matcher(string);
 		return (matcher.matches());
 	}
-
+	
+	private static int matchesEnd(String regex, String string) {
+		string = string.replaceAll("\\s$", "");
+		Pattern pattern = Pattern.compile(regex, Pattern.CASE_INSENSITIVE | Pattern.DOTALL | Pattern.MULTILINE);
+		Matcher matcher = pattern.matcher(string);
+		int start = -1;
+		while (matcher.find()) {
+			if (matcher.end() == string.length())
+				start = matcher.start();
+		}
+		return start;
+	}
+	
 	private static String searchAndReplace(String sql, List<Block> parsedPattern, String replacePattern) {
 		MatchedPattern matchedPattern = search(sql, parsedPattern, 0);
 		while (matchedPattern.start != -1) {
@@ -244,7 +276,7 @@ public class SqlTranslate {
 		}
 		return sql;
 	}
-
+	
 	private static String translateSql(String sql, List<String[]> replacementPatterns, String sessionId,
 			String oracleTempPrefix) {
 		for (int i = 0; i < replacementPatterns.size(); i++) {
@@ -256,7 +288,7 @@ public class SqlTranslate {
 		}
 		return sql;
 	}
-
+	
 	/**
 	 * This function takes SQL in one dialect and translates it into another. It
 	 * uses simple pattern replacement, so its functionality is limited.
@@ -272,7 +304,7 @@ public class SqlTranslate {
 	public static String translateSql(String sql, String sourceDialect, String targetDialect) {
 		return translateSql(sql, sourceDialect, targetDialect, null, null);
 	}
-
+	
 	/**
 	 * This function takes SQL in one dialect and translates it into another. It
 	 * uses simple pattern replacement, so its functionality is limited.The source
@@ -288,7 +320,7 @@ public class SqlTranslate {
 	public static String translateSql(String sql, String targetDialect) {
 		return translateSql(sql, targetDialect, null, null);
 	}
-
+	
 	/**
 	 * This function takes SQL in one dialect and translates it into another. It
 	 * uses simple pattern replacement, so its functionality is limited.
@@ -316,7 +348,7 @@ public class SqlTranslate {
 			String oracleTempSchema) {
 		return translateSql(sql, targetDialect, sessionId, oracleTempSchema);
 	}
-
+	
 	/**
 	 * This function takes SQL in one dialect and translates it into another. It
 	 * uses simple pattern replacement, so its functionality is limited. The source
@@ -343,7 +375,7 @@ public class SqlTranslate {
 	public static String translateSql(String sql, String targetDialect, String sessionId, String tempEmulationSchema) {
 		return translateSqlWithPath(sql, targetDialect, sessionId, tempEmulationSchema, null);
 	}
-
+	
 	/**
 	 * This function takes SQL in one dialect and translates it into another. It
 	 * uses simple pattern replacement, so its functionality is limited. The source
@@ -359,7 +391,7 @@ public class SqlTranslate {
 	public static String translateSingleStatementSql(String sql, String targetDialect) {
 		return translateSingleStatementSql(sql, targetDialect, null, null);
 	}
-
+	
 	/**
 	 * This function takes SQL in one dialect and translates it into another. It
 	 * uses simple pattern replacement, so its functionality is limited.The source
@@ -388,7 +420,7 @@ public class SqlTranslate {
 			String tempEmulationSchema) {
 		return translateSingleStatementSqlWithPath(sql, targetDialect, sessionId, tempEmulationSchema, null);
 	}
-
+	
 	/**
 	 * This function takes SQL in one dialect and translates it into another. It
 	 * uses simple pattern replacement, so its functionality is limited.The source
@@ -426,7 +458,7 @@ public class SqlTranslate {
 			throw new RuntimeException("SQL contains more than one statement: " + sql);
 		return sqlStatements[0];
 	}
-
+	
 	/**
 	 * This function takes SQL in one dialect and translates it into another. It
 	 * uses simple pattern replacement, so its functionality is limited.The source
@@ -458,9 +490,7 @@ public class SqlTranslate {
 			String tempEmulationSchema, String pathToReplacementPatterns) {
 		ensurePatternsAreLoaded(pathToReplacementPatterns);
 		if (sessionId == null) {
-			if (globalSessionId == null)
-				globalSessionId = generateSessionId();
-			sessionId = globalSessionId;
+			sessionId = getGlobalSessionId();
 		} else
 			validateSessionId(sessionId);
 		String oracleTempPrefix;
@@ -468,7 +498,7 @@ public class SqlTranslate {
 			oracleTempPrefix = "";
 		else
 			oracleTempPrefix = tempEmulationSchema + ".";
-
+		
 		List<String[]> replacementPatterns = targetToReplacementPatterns.get(targetDialect);
 		if (replacementPatterns == null) {
 			if (SOURCE_DIALECT.equals(targetDialect))
@@ -493,7 +523,7 @@ public class SqlTranslate {
 		}
 		return sql;
 	}
-
+	
 	private static void validateSessionId(String sessionId) {
 		if (sessionId.length() != SESSION_ID_LENGTH)
 			throw new RuntimeException(
@@ -504,7 +534,7 @@ public class SqlTranslate {
 			if (!Character.isLetterOrDigit(sessionId.charAt(i)))
 				throw new RuntimeException("Illegal character in session ID");
 	}
-
+	
 	/**
 	 * Generates a random string that can be used as a unique session identifier
 	 * 
@@ -520,7 +550,7 @@ public class SqlTranslate {
 		}
 		return sb.toString();
 	}
-
+	
 	private static List<String> line2columns(String line) {
 		List<String> columns = StringUtils.safeSplit(line, ',');
 		for (int i = 0; i < columns.size(); i++) {
@@ -533,7 +563,7 @@ public class SqlTranslate {
 		}
 		return columns;
 	}
-
+	
 	private static void ensurePatternsAreLoaded(String pathToReplacementPatterns) {
 		if (targetToReplacementPatterns != null)
 			return;
@@ -575,10 +605,10 @@ public class SqlTranslate {
 			lock.unlock();
 		}
 	}
-
+	
 	public static String[] check(String sql, String targetDialect) {
 		List<String> warnings = new ArrayList<String>();
-
+		
 		// temp table names:
 		Pattern pattern = Pattern.compile("#[0-9a-zA-Z_]+");
 		Matcher matcher = pattern.matcher(sql);
@@ -586,12 +616,12 @@ public class SqlTranslate {
 		while (matcher.find())
 			if (matcher.group().length() > MAX_ORACLE_TABLE_NAME_LENGTH - SESSION_ID_LENGTH - 1)
 				longTempNames.add(matcher.group());
-
+		
 		for (String longName : longTempNames)
 			warnings.add("Temp table name '" + longName + "' is too long. Temp table names should be shorter than "
 					+ (MAX_ORACLE_TABLE_NAME_LENGTH - SESSION_ID_LENGTH)
 					+ " characters to prevent Oracle from crashing.");
-
+		
 		// normal table names:
 		pattern = Pattern.compile("(create|drop|truncate)\\s+table +[0-9a-zA-Z_]+");
 		matcher = pattern.matcher(sql.toLowerCase());
@@ -604,10 +634,10 @@ public class SqlTranslate {
 		for (String longName : longNames)
 			warnings.add("Table name '" + longName + "' is too long. Table names should be shorter than "
 					+ MAX_ORACLE_TABLE_NAME_LENGTH + " characters to prevent Oracle from crashing.");
-
+		
 		return warnings.toArray(new String[warnings.size()]);
 	}
-
+	
 	/**
 	 * Forces the replacement patterns to be loaded from the specified path. Useful
 	 * for debugging.
@@ -620,4 +650,14 @@ public class SqlTranslate {
 		targetToReplacementPatterns = null;
 		ensurePatternsAreLoaded(pathToReplacementPatterns);
 	}
+	
+	/**
+	 * Get the global session ID. This ID is prefixed to all table names in the temp
+	 * emulation schema to avoid collisions between sessions.
+	 */
+	public static String getGlobalSessionId() {
+		if (globalSessionId == null) 
+			globalSessionId = generateSessionId();
+		return(globalSessionId);
+	}
 }
